package data_import

import (
	"adm-management/consts"
	"adm-management/errors"
	"adm-management/model"
	v1 "adm-management/pb/v1"
	"context"

	"encoding/json"
	"fmt"
	"strings"

	"git.getensh.com/common/gopkgsv2/database"
	"git.getensh.com/common/gopkgsv2/logger"
	"go.uber.org/zap"
	"google.golang.org/grpc/status"
	"gorm.io/gorm"
)

func DataImportTemplate(ctx context.Context, req *v1.DataImportTemplateRequest) (reply *v1.DataImportTemplateReply, err error) {

	defer func() {
		if r := recover(); r != nil {
			err = fmt.Errorf("%+v", r)
			e := &status.Status{}
			if er := json.Unmarshal([]byte(err.Error()), e); er != nil {
				logger.Error("err",
					zap.String("system_err", err.Error()),
					zap.Stack("stacktrace"))
			}
		}
	}()

	reply = &v1.DataImportTemplateReply{}

	db := database.DB()
	if req.TemplateName == "" {
		db = db.Where("template_name is NOT null")
	}
	if req.TemplateName != "" {
		db = db.Where("template_name like ?", "%"+req.TemplateName+"%")
	}

	db = db.Order("created_at desc")

	pageSize := consts.PageSize
	if req.PageSize != 0 {
		pageSize = int(req.PageSize)
	}

	// 构造分页类
	pagination := model.NewPagination(int(req.Page), pageSize, 0).GetLimitOffset()

	count, err := model.NewDataTemplate().Count(db)
	if err != nil && err != gorm.ErrRecordNotFound {
		return reply, errors.SystemError
	}

	if err == gorm.ErrRecordNotFound || count == 0 {
		return reply, nil
	}

	list, err := model.NewDataTemplate().List(db, pagination)

	if err != nil && err != gorm.ErrRecordNotFound {
		return reply, errors.SystemError
	}

	if err == gorm.ErrRecordNotFound {
		pagination.CalPage(int(count))

		reply.CurrentPage = int64(pagination.CurrentPage)
		reply.PerPage = int64(pagination.PerPage)
		reply.Total = int64(pagination.Total)
		reply.FirstPage = int64(pagination.FirstPage)
		reply.LastPage = int64(pagination.LastPage)
		reply.PrevPage = int64(pagination.PrevPage)
		reply.NextPage = int64(pagination.NextPage)
		return reply, nil
	}

	var t []string
	var t2 []*v1.RequestList
	var t3 []string
	reply.List = make([]*v1.DataImportTemplateList, 0, len(list))
	for _, v := range list {
		for _, value := range strings.Split(v.TaskIds, ",") {
			tasks, err := model.NewTaskList().Get(database.DB().Where("task_id = ?", value))
			if err != nil && err != gorm.ErrRecordNotFound {
				return nil, err
			}
			if err == gorm.ErrRecordNotFound {
				return reply, nil
			}
			t = append(t, tasks.TaskName+":"+tasks.Desc)
		}

		var re *v1.RequestList
		desc := ""
		for _, value := range strings.Split(v.Request, ",") {

			err = db.Raw("select `desc` from t_adm_field_management where field = ?", value).Find(&desc).Error
			re = &v1.RequestList{
				Request: value,
				Desc:    desc,
			}
			fmt.Println(desc)
			t2 = append(t2, re)
		}

		for _, value := range strings.Split(v.TaskIds, ",") {
			tasks, err := model.NewTaskList().Get(database.DB().Where("task_id = ?", value))
			if err != nil && err != gorm.ErrRecordNotFound {
				return nil, err
			}
			if err == gorm.ErrRecordNotFound {
				return reply, nil
			}
			t3 = append(t3, tasks.TaskName)
		}

		reply.List = append(reply.List, &v1.DataImportTemplateList{
			Id:           v.Id,
			TemplateName: v.TemplateName,
			TaskDesc:     t,
			Request:      t2,
			TaskName:     t3,
		})
		t = []string{}
		t2 = []*v1.RequestList{}
		t3 = []string{}
	}

	// 计算分页结果
	pagination.CalPage(int(count))

	reply.CurrentPage = int64(pagination.CurrentPage)
	reply.PerPage = int64(pagination.PerPage)
	reply.Total = int64(pagination.Total)
	reply.FirstPage = int64(pagination.FirstPage)
	reply.LastPage = int64(pagination.LastPage)
	reply.PrevPage = int64(pagination.PrevPage)
	reply.NextPage = int64(pagination.NextPage)
	return reply, nil
}
