package data_management

import (
	"adm-management/errors"
	"adm-management/model"
	v1 "adm-management/pb/v1"
	"context"
	"encoding/json"
	"fmt"

	"git.getensh.com/common/gopkgsv2/database"

	"git.getensh.com/common/gopkgsv2/logger"
	"go.uber.org/zap"
	"google.golang.org/grpc/status"
)

func Switch(ctx context.Context, req *v1.SwitchRequest) (reply *v1.SwitchReply, err error) {
	reply = &v1.SwitchReply{}

	// 捕获各个task中的异常并返回给调用者
	defer func() {
		if r := recover(); r != nil {
			err = fmt.Errorf("%+v", r)
			e := &status.Status{}
			if er := json.Unmarshal([]byte(err.Error()), e); er != nil {
				logger.Error("err",
					zap.String("system_err", err.Error()),
					zap.Stack("stacktrace"))
			}
		}
	}()

	if req.IsOn == true {

		if err = model.NewRelation().Update(database.DB().Where("task_id = ?", req.TaskId), map[string]interface{}{"is_on": 1}); err != nil {
			return reply, errors.SystemError
		}

	}

	if req.IsOn == false {

		if err = model.NewRelation().Update(database.DB().Where("task_id = ?", req.TaskId), map[string]interface{}{"is_on": 0}); err != nil {
			return reply, errors.SystemError
		}
	}

	return reply, nil
}
