package data_management

import (
	"adm-management/errors"
	"adm-management/model"
	v1 "adm-management/pb/v1"

	"context"

	"encoding/json"
	"fmt"

	"git.getensh.com/common/gopkgsv2/database"
	"git.getensh.com/common/gopkgsv2/logger"
	"go.uber.org/zap"
	"google.golang.org/grpc/status"
	"gorm.io/gorm"
)

type TableFields struct {
	Field   string
	Type    string
	Null    string
	Key     string
	Default string
	Extra   string
	Comment string
}

func TableStruct(ctx context.Context, req *v1.TableStructRequest) (reply *v1.TableStructReply, err error) {
	defer func() {
		if r := recover(); r != nil {
			err = fmt.Errorf("%+v", r)
			e := &status.Status{}
			if er := json.Unmarshal([]byte(err.Error()), e); er != nil {
				logger.Error("err",
					zap.String("system_err", err.Error()),
					zap.Stack("stacktrace"))
			}
		}
	}()
	reply = &v1.TableStructReply{}
	db := database.DB()
	var dataBase string
	err = db.Raw("select db from t_adm_data_management where table_name = ?", req.TableName).Find(&dataBase).Error
	if err != nil {
		if err == gorm.ErrRecordNotFound {
			return reply, nil
		}
		return reply, errors.SystemError
	}

	var structInfo []TableFields
	sql := "show full columns from " + dataBase + "." + req.TableName
	err = db.Raw(sql).Scan(&structInfo).Error
	if err != nil {
		if err == gorm.ErrRecordNotFound {
			return reply, nil
		}
		return reply, errors.SystemError
	}

	var fieldNameList []string
	for _, v := range structInfo {
		fieldNameList = append(fieldNameList, v.Field)
	}

	fields := []model.AdmFieldList{}
	if len(fieldNameList) > 0 {
		sql = "select * from t_adm_field_management where field in ?"
		err = db.Raw(sql, fieldNameList).Scan(&fields).Error
		if err != nil {
			if err == gorm.ErrRecordNotFound {
				return reply, nil
			}
			return reply, errors.SystemError
		}
	}

	fieldMap := make(map[string]string)

	for _, v := range fields {
		fieldMap[v.Field] = v.Desc
	}

	for _, v := range structInfo {
		reply.List = append(reply.List, &v1.TableStruct{
			FieldName: v.Field,
			Desc:      fieldMap[v.Field],
		})
	}

	return reply, nil
}
