package style_map_management

import (
	"adm-management/errors"
	v1 "adm-management/pb/v1"
	"context"
	"encoding/json"
	"fmt"
	"time"

	"git.getensh.com/common/gopkgsv2/database"

	"gorm.io/gorm"

	"git.getensh.com/common/gopkgsv2/logger"
	"go.uber.org/zap"
	"google.golang.org/grpc/status"
)

func editMap(db *gorm.DB, req *v1.EditMapRequest) (err error) {
	if req.StyleId != "" {
		// 检查style id是否存在
		id := ""
		err = db.Raw("SELECT style_id from db_adm_ads.t_adm_ads5 where style_id = ?", req.StyleId).Find(&id).Error
		if err != nil {
			if err == gorm.ErrRecordNotFound {
				return errors.StyleIdNotExistError
			}
			return errors.SystemError
		}
	}

	err = db.Exec("UPDATE db_adm_dws.t_adm_dws13 SET style_id = ?, updated_at = ? WHERE third_style_id = ?", req.StyleId, time.Now().Unix(), req.ThirdStyleId).Error
	if err != nil {
		if err == gorm.ErrRecordNotFound {
			return nil
		}
		return errors.SystemError
	}

	//TODO 更新ads11
	err = db.Exec("UPDATE db_adm_ads.t_adm_ads11 SET style_id = ?, updated_at = ?  WHERE third_style_id = ?", req.StyleId, time.Now().Unix(), req.ThirdStyleId).Error
	if err != nil {
		if err == gorm.ErrRecordNotFound {
			return nil
		}
		return errors.SystemError
	}

	return nil

}
func EditMap(ctx context.Context, req *v1.EditMapRequest) (reply *v1.EditMapReply, err error) {
	reply = &v1.EditMapReply{Code: 1}
	// 捕获各个task中的异常并返回给调用者
	defer func() {
		if r := recover(); r != nil {
			err = fmt.Errorf("%+v", r)
			e := &status.Status{}
			if er := json.Unmarshal([]byte(err.Error()), e); er != nil {
				logger.Error("err",
					zap.String("system_err", err.Error()),
					zap.Stack("stacktrace"))
			}
		}
	}()
	tdb := database.DB().Begin()
	err = editMap(tdb, req)
	if err != nil {
		tdb.Rollback()
	} else {
		tdb.Commit()
	}
	return reply, err

	db := database.DB()
	if req.StyleId == "" {
		err = db.Exec("UPDATE db_adm_dws.t_adm_dws13 SET style_id = ?, updated_at = ? WHERE third_style_id = ?", req.StyleId, time.Now().Unix(), req.ThirdStyleId).Error
		if err != nil {
			if err == gorm.ErrRecordNotFound {
				return reply, nil
			}
			return reply, errors.SystemError
		}
		reply.Code = 1
		return reply, nil
	} else {
		id := ""
		err = db.Raw("SELECT style_id from db_adm_ads.t_adm_ads5 where style_id = ?", req.StyleId).Find(&id).Error
		if err != nil {
			if err == gorm.ErrRecordNotFound {
				return reply, nil
			}
			return reply, errors.SystemError
		}

		if id == "" {
			reply.Code = 0
		} else {

			err = db.Exec("UPDATE db_adm_dws.t_adm_dws13 SET style_id = ?, updated_at = ?  WHERE third_style_id = ?", id, time.Now().Unix(), req.ThirdStyleId).Error
			if err != nil {
				if err == gorm.ErrRecordNotFound {
					return reply, nil
				}
				return reply, errors.SystemError
			}
			reply.Code = 1
			return reply, nil

		}

	}

	return reply, nil

}
