package task_management

import (
	"context"
	"encoding/json"
	"fmt"

	"adm-management/errors"
	"adm-management/model"
	v1 "adm-management/pb/v1"

	"git.getensh.com/common/gopkgsv2/database"
	"git.getensh.com/common/gopkgsv2/logger"
	"go.uber.org/zap"
	"google.golang.org/grpc/status"
	"gorm.io/gorm"
)

func SearchTask(ctx context.Context, req *v1.SearchTaskRequest) (reply *v1.SearchTaskReply, err error) {
	reply = &v1.SearchTaskReply{}

	// 捕获各个task中的异常并返回给调用者
	defer func() {
		if r := recover(); r != nil {
			err = fmt.Errorf("%+v", r)
			e := &status.Status{}
			if er := json.Unmarshal([]byte(err.Error()), e); er != nil {
				logger.Error("err",
					zap.String("system_err", err.Error()),
					zap.Stack("stacktrace"))
			}
		}
	}()

	if req.TaskName != "" {
		// 任务名搜索
		// 构造分页类
		pagination := model.NewPagination(0, 100000, 0).GetLimitOffset()
		list, err := model.NewTaskList().List(database.DB().Where("task_name like ?", "%"+req.TaskName+"%"), pagination)
		if err != nil && err != gorm.ErrRecordNotFound {
			return reply, errors.SystemError
		}

		if err == gorm.ErrRecordNotFound {
			return reply, nil
		}

		reply.List = make([]*v1.SearchTask, 0, len(list))
		for _, v := range list {
			reply.List = append(reply.List, &v1.SearchTask{
				TaskName: v.TaskName,
				Desc:     v.Desc,
			})
		}
	}

	if req.TaskName == "" {
		// 任务名搜索
		// 构造分页类
		pagination := model.NewPagination(0, 100000, 0).GetLimitOffset()
		list, err := model.NewTaskList().List(database.DB().Where("task_name is NOT null"), pagination)
		if err != nil && err != gorm.ErrRecordNotFound {
			return reply, errors.SystemError
		}

		if err == gorm.ErrRecordNotFound {
			return reply, nil
		}

		reply.List = make([]*v1.SearchTask, 0, len(list))
		for _, v := range list {
			reply.List = append(reply.List, &v1.SearchTask{
				TaskName: v.TaskName,
				Desc:     v.Desc,
			})
		}
	}

	return reply, nil
}
