package model

import (
	"git.getensh.com/common/gopkgsv2/database"
	"gorm.io/gorm"
)

type DataTemplateModel interface {
	List(db *gorm.DB, pagination *Pagination) ([]AdmDataTemplate, error)
	Count(db *gorm.DB) (int64, error)
	Update(db *gorm.DB, values interface{}) error
	Get(db *gorm.DB) (*AdmDataTemplate, error)
}

type AdmDataTemplate struct {
	Id           int64  `gorm:"column:id"           json:"id"           form:"id"`
	TemplateName string `gorm:"column:template_name"    json:"template_name"    form:"template_name"`
	Request      string `gorm:"column:request"    json:"request"    form:"request"`
	TaskIds      string `gorm:"column:task_ids"     json:"task_ids"     form:"task_ids"`
	CreatedAt    int64  `gorm:"column:created_at"   json:"created_at"   form:"created_at"`
	UpdatedAt    int64  `gorm:"column:updated_at"   json:"updated_at"   form:"updated_at"`
}

type defaultDataTemplate struct {
	tableName string
	fields    string
}

func NewDataTemplate() DataTemplateModel {
	return &defaultDataTemplate{
		tableName: "t_adm_data_template",
		fields:    "`id`, `template_name`, `request`, `task_ids`, `created_at`, `updated_at`",
	}
}

func (d *defaultDataTemplate) List(db *gorm.DB, pagination *Pagination) ([]AdmDataTemplate, error) {
	var res []AdmDataTemplate
	err := database.List(db, &res, database.Option{
		TableName: d.tableName,
		Fields:    d.fields,
		Limit:     pagination.Limit,
		OffSet:    pagination.Offset,
	})

	return res, err
}

func (d *defaultDataTemplate) Count(db *gorm.DB) (int64, error) {
	return database.Count(db, database.Option{
		TableName: d.tableName,
	})
}

func (d *defaultDataTemplate) Update(db *gorm.DB, values interface{}) error {
	return database.Update(db, values, database.Option{
		TableName: d.tableName,
	})
}

func (d *defaultDataTemplate) Get(db *gorm.DB) (*AdmDataTemplate, error) {
	var res AdmDataTemplate
	err := database.Get(db, &res, database.Option{
		TableName: d.tableName,
		Fields:    d.fields,
	})

	return &res, err
}
