package model

import (
	"git.getensh.com/common/gopkgsv2/database"
	"gorm.io/gorm"
)

type StyleMapModel interface {
	List(db *gorm.DB, pagination *Pagination) ([]AdmStyleMap, error)
	Count(db *gorm.DB) (int64, error)
	Update(db *gorm.DB, values interface{}) error
	Get(db *gorm.DB) (*AdmStyleMap, error)
}

type AdmStyleMap struct {
	Id              int64  `gorm:"column:id"                json:"id"                form:"id"`
	Source          string `gorm:"column:source"            json:"source"            form:"source"`
	ThirdBrandId    string `gorm:"column:third_brand_id"    json:"third_brand_id"    form:"third_brand_id"`
	ThirdBrandName  string `gorm:"column:third_brand_name"  json:"third_brand_name"  form:"third_brand_name"`
	ThirdSeriesId   string `gorm:"column:third_series_id"   json:"third_series_id"   form:"third_series_id"`
	ThirdSeriesName string `gorm:"column:third_series_name" json:"third_series_name" form:"third_series_name"`
	ThirdStyleId    string `gorm:"column:third_style_id"    json:"third_style_id"    form:"third_style_id"`
	ThirdStyleName  string `gorm:"column:third_style_name"  json:"third_style_name"  form:"third_style_name"`
	ThirdMaker      string `gorm:"column:third_maker"       json:"third_maker"       form:"third_maker"`
	ModelYear       string `gorm:"column:model_year"        json:"model_year"        form:"model_year"`
	StyleId         string `gorm:"column:style_id"          json:"style_id"          form:"style_id"`
	CreatedAt       int64  `gorm:"column:created_at"        json:"created_at"        form:"created_at"`
	UpdatedAt       int64  `gorm:"column:updated_at"        json:"updated_at"        form:"updated_at"`
}

type defaultStyleMap struct {
	tableName string
	fields    string
}

func NewStyleMap() StyleMapModel {
	return &defaultStyleMap{
		tableName: "db_adm_dws.t_adm_dws13",
		fields:    "`id`, `source`, `third_brand_id`, `third_brand_name`, `third_series_id`, `third_series_name`, `third_style_id`, `third_style_name`, `third_maker`,`model_year`,`style_id`,`created_at`,`updated_at`",
	}
}

func (d *defaultStyleMap) List(db *gorm.DB, pagination *Pagination) ([]AdmStyleMap, error) {
	var res []AdmStyleMap
	err := database.List(db, &res, database.Option{
		TableName: d.tableName,
		Fields:    d.fields,
		Limit:     pagination.Limit,
		OffSet:    pagination.Offset,
	})

	return res, err
}

func (d *defaultStyleMap) Count(db *gorm.DB) (int64, error) {
	return database.Count(db, database.Option{
		TableName: d.tableName,
	})
}

func (d *defaultStyleMap) Update(db *gorm.DB, values interface{}) error {
	return database.Update(db, values, database.Option{
		TableName: d.tableName,
	})
}

func (d *defaultStyleMap) Get(db *gorm.DB) (*AdmStyleMap, error) {
	var res AdmStyleMap
	err := database.Get(db, &res, database.Option{
		TableName: d.tableName,
		Fields:    d.fields,
	})

	return &res, err
}

type SourceInfo struct {
	Source string `gorm:"column:source"      json:"source"      form:"source"`
}
